@@ -16,10 +16,22 @@ sub new {
                           'method' => 'POST',
                           'url'    => 'session'
         },
+        'getSessions' => {
+                          'method' => 'GET',
+                          'url'    => 'sessions'
+        },
         'getCapabilities' => {
                           'method' => 'GET',
                           'url'    => 'session/:sessionId'
         },
+        'setTimeout' => {
+                        'method' => 'POST',
+                        'url'    => 'session/:sessionId/timeouts'
+        },
+        'setAsyncScriptTimeout' => {
+                        'method' => 'POST',
+                        'url'    => 'session/:sessionId/timeouts/async_script'
+        },
         'setImplicitWaitTimeout' => {
                         'method' => 'POST',
                         'url'    => 'session/:sessionId/timeouts/implicit_wait'
@@ -36,6 +48,22 @@ sub new {
                 'method' => 'GET',
                 'url' => "session/:sessionId/window_handles"
         },
+        'getWindowSize' => {
+                'method' => 'GET',
+                'url' => "session/:sessionId/window/:windowHandle/size"
+        },
+        'getWindowPosition' => {
+                'method' => 'GET',
+                'url' => "session/:sessionId/window/:windowHandle/position"
+        },
+        'setWindowSize' => {
+                'method' => 'POST',
+                'url' => "session/:sessionId/window/:windowHandle/size"
+        },
+        'setWindowPosition' => {
+                'method' => 'POST',
+                'url' => "session/:sessionId/window/:windowHandle/position"
+        },
         'getCurrentUrl' => {
                            'method' => 'GET',
                            'url' => "session/:sessionId/url"
@@ -140,6 +168,10 @@ sub new {
                'method' => 'POST',
                'url' => "session/:sessionId/element/:id/value"
         },
+        'sendKeysToActiveElement' => {
+               'method' => 'POST',
+               'url' => "session/:sessionId/keys"
+        },
         'sendModifier' => {
                'method' => 'POST',
                'url' => "session/:sessionId/modifier"
@@ -279,6 +311,7 @@ sub get_params {
     $url =~ s/:name/$args->{'name'}/;
     $url =~ s/:propertyName/$args->{'property_name'}/;
     $url =~ s/:other/$args->{'other'}/;
+    $url =~ s/:windowHandle/$args->{'window_handle'}/;
 
     $data->{'method'} = $self->{$command}->{'method'};
     $data->{'url'}    = $url;
