@@ -11,7 +11,7 @@ use constant KEYS => {
     'cancel'	 => "\N{U+E001}",
     'help'	 => "\N{U+E002}",
     'backspace'	 => "\N{U+E003}",
-    'Tab'	 => "\N{U+E004}",
+    'tab'	 => "\N{U+E004}",
     'clear'	 => "\N{U+E005}",
     'return'	 => "\N{U+E006}",
     'enter'	 => "\N{U+E007}",
